@@ -22,7 +22,7 @@ class ComponentInstance:
     def __init__(
         self,
         component_name: str,
-        instance_name: str,
+        instance_id: str,
         init_state_func: Optional[Callable],
         init_state_params: Optional[Dict[str, Any]],
         save_state_func: Optional[Callable],
@@ -31,14 +31,15 @@ class ComponentInstance:
         update_routes: Dict[str, List[Route]],
         logging_level: str = "WARNING",
         disabled: bool = False,
+        cache_ttl: int = DEFAULT_KEY_TTL,
     ):
         """Creates a new instance of a Motion component.
 
         Args:
-            name (str):
+            component_name (str):
                 Name of the component we are creating an instance of.
-            instance_name (str):
-                Name of the instance we are creating.
+            instance_id (str):
+                ID of the instance we are creating.
             logging_level (str, optional):
                 Logging level for the Motion logger. Uses the logging library.
                 Defaults to "WARNING".
@@ -51,12 +52,14 @@ class ComponentInstance:
         atexit.register(self.shutdown)
 
         # Create instance name
-        self._instance_name = instance_name
+        self._instance_name = f"{self._component_name}__{instance_id}"
+        self._cache_ttl = cache_ttl
 
         self.running = False
         self.disabled = disabled
         self._executor = Executor(
             self._instance_name,
+            cache_ttl=self._cache_ttl,
             init_state_func=init_state_func,
             init_state_params=init_state_params if init_state_params else {},
             save_state_func=save_state_func,
@@ -229,7 +232,7 @@ class ComponentInstance:
             return state["value"] + value
 
         @C.update("add")
-        def add(state, value, serve_result):
+        def add(state, value):
             return {"value": state["value"] + value}
 
         @C.serve("multiply")
@@ -238,9 +241,9 @@ class ComponentInstance:
 
         if __name__ == "__main__":
             c = C() # Create instance of C
-            c.run("add", kwargs={"value": 1})
+            c.run("add", props={"value": 1})
             c.flush_update("add") # (1)!
-            c.run("add", kwargs={"value": 2}) # This will use the updated state
+            c.run("add", props={"value": 2}) # This will use the updated state
 
         # 1. Waits for the update op to finish, then updates the state
         ```
@@ -249,8 +252,7 @@ class ComponentInstance:
             dataflow_key (str): Key of the dataflow.
 
         Raises:
-            RuntimeError: If the component instance was initialized to
-            be disabled.
+            RuntimeError: If the component instance was initialized as disabled.
         """
         if self.disabled:
             raise RuntimeError("Cannot run a disabled component instance.")
@@ -261,8 +263,7 @@ class ComponentInstance:
         self,
         # *,
         dataflow_key: str,
-        kwargs: Dict[str, Any] = {},
-        cache_ttl: int = DEFAULT_KEY_TTL,
+        props: Dict[str, Any] = {},
         ignore_cache: bool = False,
         force_refresh: bool = False,
         flush_update: bool = False,
@@ -286,19 +287,19 @@ class ComponentInstance:
             return state["value"] + value
 
         @C.update("add")
-        def add(state, value, serve_result):
+        def add(state, value):
             return {"value": state["value"] + value}
 
         if __name__ == "__main__":
             c = C() # Create instance of C
-            c.run("add", kwargs={"value": 1}, flush_update=True) # (1)!
-            c.run("add", kwargs={"value": 1}) # Returns 1
-            c.run("add", kwargs={"value": 2}, flush_update=True) # (2)!
+            c.run("add", props={"value": 1}, flush_update=True) # (1)!
+            c.run("add", props={"value": 1}) # Returns 1
+            c.run("add", props={"value": 2}, flush_update=True) # (2)!
 
-            c.run("add", kwargs={"value": 3})
+            c.run("add", props={"value": 3})
             time.sleep(3) # Wait for the previous update op to finish
 
-            c.run("add", kwargs={"value": 3}, force_refresh=True) # (3)!
+            c.run("add", props={"value": 3}, force_refresh=True) # (3)!
 
         # 1. Waits for the update op to finish, then updates the state
         # 2. Returns 2, result state["value"] = 4
@@ -309,16 +310,13 @@ class ComponentInstance:
 
         Args:
             dataflow_key (str): Key of the dataflow to run.
-            kwargs (Dict[str, Any]): Keyword arguments to pass into the
+            props (Dict[str, Any]): Keyword arguments to pass into the
                 dataflow ops, in addition to the state.
-            cache_ttl (int, optional):
-                How long the serveence result should live in a cache (in
-                seconds). Defaults to 1 day (60 * 60 * 24).
             ignore_cache (bool, optional):
                 If True, ignores the cache and runs the serve op. Does not
                 force refresh the state. Defaults to False.
             force_refresh (bool, optional): Read the latest value of the
-                state before running an serveence call, otherwise a stale
+                state before running an serve call, otherwise a stale
                 version of the state or a cached result may be used.
                 Defaults to False.
             flush_update (bool, optional):
@@ -327,8 +325,13 @@ class ComponentInstance:
                 yet, the update op runs anyways. Force refreshes the
                 state after the update op completes. Defaults to False.
 
+         Raises:
+            ValueError: If more than one dataflow key-value pair is passed.
+            RuntimeError:
+                If the component instance was initialized as disabled.
+
         Returns:
-            Any: Result of the serveence call. Might take a long time
+            Any: Result of the serve call. Might take a long time
             to run if `flush_update = True` and the update operation is
             computationally expensive.
         """
@@ -337,8 +340,7 @@ class ComponentInstance:
 
         serve_result = self._executor.run(
             key=dataflow_key,
-            kwargs=kwargs,
-            cache_ttl=cache_ttl,
+            props=props,
             ignore_cache=ignore_cache,
             force_refresh=force_refresh,
             flush_update=flush_update,
@@ -350,8 +352,7 @@ class ComponentInstance:
         self,
         # *,
         dataflow_key: str,
-        kwargs: Dict[str, Any] = {},
-        cache_ttl: int = DEFAULT_KEY_TTL,
+        props: Dict[str, Any] = {},
         ignore_cache: bool = False,
         force_refresh: bool = False,
         flush_update: bool = False,
@@ -373,7 +374,7 @@ class ComponentInstance:
 
         async def main():
             c = C()
-            await c.arun("sleep", kwargs={"value": 1})
+            await c.arun("sleep", props={"value": 1})
 
         if __name__ == "__main__":
             asyncio.run(main())
@@ -381,16 +382,13 @@ class ComponentInstance:
 
         Args:
             dataflow_key (str): Key of the dataflow to run.
-            kwargs (Dict[str, Any]): Keyword arguments to pass into the
+            props (Dict[str, Any]): Keyword arguments to pass into the
                 dataflow ops, in addition to the state.
-            cache_ttl (int, optional):
-                How long the serveence result should live in a cache (in
-                seconds). Defaults to 1 day (60 * 60 * 24).
             ignore_cache (bool, optional):
                 If True, ignores the cache and runs the serve op. Does not
                 force refresh the state. Defaults to False.
             force_refresh (bool, optional): Read the latest value of the
-                state before running an serveence call, otherwise a stale
+                state before running an serve call, otherwise a stale
                 version of the state or a cached result may be used.
                 Defaults to False.
             flush_update (bool, optional):
@@ -398,26 +396,22 @@ class ComponentInstance:
                 returning. If the update queue hasn't reached batch_size
                 yet, the update op runs anyways. Force refreshes the
                 state after the update op completes. Defaults to False.
-            **kwargs:
-                Keyword arguments for the serve and update ops. You can only
-                pass in one pair.
 
         Raises:
             ValueError: If more than one dataflow key-value pair is passed.
-            RuntimeError: If the component instance was initialized to
-            be disabled.
+            RuntimeError:
+                If the component instance was initialized as disabled.
 
         Returns:
-            Awaitable[Any]: Awaitable Result of the serveence call.
+            Awaitable[Any]: Awaitable Result of the serve call.
         """
         if self.disabled:
             raise RuntimeError("Cannot run a disabled component instance.")
 
         serve_result = await self._executor.arun(
             key=dataflow_key,
-            kwargs=kwargs,
+            props=props,
             # value=value,
-            cache_ttl=cache_ttl,
             ignore_cache=ignore_cache,
             force_refresh=force_refresh,
             flush_update=flush_update,
